import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataKubernetesServiceConfig extends cdktf.TerraformMetaArguments {
    /**
    * metadata block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service#metadata DataKubernetesService#metadata}
    */
    readonly metadata: DataKubernetesServiceMetadata;
}
export declare class DataKubernetesServiceSpecPort extends cdktf.ComplexComputedList {
    get name(): string;
    get nodePort(): number;
    get port(): number;
    get protocol(): string;
    get targetPort(): string;
}
export declare class DataKubernetesServiceSpec extends cdktf.ComplexComputedList {
    get clusterIp(): string;
    get externalIps(): string[];
    get externalName(): string;
    get externalTrafficPolicy(): string;
    get healthCheckNodePort(): number;
    get loadBalancerIp(): string;
    get loadBalancerSourceRanges(): string[];
    get port(): cdktf.IResolvable;
    get publishNotReadyAddresses(): cdktf.IResolvable;
    get selector(): {
        [key: string]: string;
    };
    get sessionAffinity(): string;
    get type(): string;
}
export declare class DataKubernetesServiceStatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    get hostname(): string;
    get ip(): string;
}
export declare class DataKubernetesServiceStatusLoadBalancer extends cdktf.ComplexComputedList {
    get ingress(): cdktf.IResolvable;
}
export declare class DataKubernetesServiceStatus extends cdktf.ComplexComputedList {
    get loadBalancer(): cdktf.IResolvable;
}
export interface DataKubernetesServiceMetadata {
    /**
    * An unstructured key value map stored with the service that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service#annotations DataKubernetesService#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Map of string keys and values that can be used to organize and categorize (scope and select) the service. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service#labels DataKubernetesService#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of the service, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service#name DataKubernetesService#name}
    */
    readonly name?: string;
    /**
    * Namespace defines the space within which name of the service must be unique.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service#namespace DataKubernetesService#namespace}
    */
    readonly namespace?: string;
}
export declare function dataKubernetesServiceMetadataToTerraform(struct?: DataKubernetesServiceMetadataOutputReference | DataKubernetesServiceMetadata): any;
export declare class DataKubernetesServiceMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataKubernetesServiceMetadata | undefined;
    set internalValue(value: DataKubernetesServiceMetadata | undefined);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get generation(): number;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    get resourceVersion(): string;
    get uid(): string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/kubernetes/d/service kubernetes_service}
*/
export declare class DataKubernetesService extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/service kubernetes_service} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataKubernetesServiceConfig
    */
    constructor(scope: Construct, id: string, config: DataKubernetesServiceConfig);
    get id(): string;
    spec(index: string): DataKubernetesServiceSpec;
    status(index: string): DataKubernetesServiceStatus;
    private _metadata;
    get metadata(): DataKubernetesServiceMetadataOutputReference;
    putMetadata(value: DataKubernetesServiceMetadata): void;
    get metadataInput(): DataKubernetesServiceMetadata | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
